@@ -18,8 +18,11 @@ class HigherPriceException(Exception): pass
 # internal static variables declaration
 
 HOMELOAD_TO = 5
-PAGELOAD_TO = 1
-PAGEJS_TO = 0.5
+PAGELOAD_TO = 2
+PAGEJS_TO = 1
+
+FACTOR_TO = 3
+TIMEOUTS_EDITED = False
 
 FILTER_REAL = 'live'
 FILTER_PRACTICE = 'demo'
@@ -56,15 +59,13 @@ process_stockinfo = [
 	{'class_name':'search-input', 'action':'click', 'sleep':PAGEJS_TO},
 	{'class_name':'search-input', 'index':1, 'action':'send_keys', 'action_parameters':'{TICKER}', 'sleep':PAGELOAD_TO},
 	{'class_name':'item-wrapper', 'action':'click', 'sleep':PAGELOAD_TO},
+	{'class_name':'trading-chart-layout-button', 'action':'click', 'sleep':PAGELOAD_TO},
 	{'class_name':'sidebar-header-option', 'index':0, 'action':'click', 'sleep':PAGEJS_TO},
-	{'class_name':'trading-chart-layout-button', 'action':'click', 'sleep':PAGELOAD_TO, 'filter':FILTER_REAL},
 	{'class_name':'instrument-name', 'action':'store_text', 'action_parameters':'name'},
 	{'class_name':'ticker', 'action':'store_text', 'action_parameters':'ticker'},
 	{'class_name':'market-status', 'action':'store_text', 'action_parameters':'market_status_full'},
-	{'class_name':'price-buy', 'action':'store_text', 'action_parameters':'full_price_buy', 'filter':FILTER_PRACTICE},
-	{'class_name':'price-sell', 'action':'store_text', 'action_parameters':'full_price_sell', 'filter':FILTER_PRACTICE},
-	{'class_name':'priceBuy', 'action':'store_text', 'action_parameters':'full_price_buy', 'filter':FILTER_REAL},
-	{'class_name':'priceSell', 'action':'store_text', 'action_parameters':'full_price_sell', 'filter':FILTER_REAL}
+	{'class_name':'priceBuy', 'action':'store_text', 'action_parameters':'full_price_buy'},
+	{'class_name':'priceSell', 'action':'store_text', 'action_parameters':'full_price_sell'}
 ]
 
 process_buy = [
@@ -100,20 +101,52 @@ def checkfilterpassed(f):
 
 # external functions declaration
 
+# multiplies all sleeps in the process p by the factor FACTOR_TO
+def update_process_sleep(p, increase):
+	for i in range(0, len(p)):
+		if not p[i].get('sleep') is None:
+			if increase: p[i]['sleep'] *= FACTOR_TO
+			else: p[i]['sleep'] /= FACTOR_TO
+		if p[i].get('action_parameters') is None: continue
+		if type(p[i].get('action_parameters')) == list: p[i]['action_parameters'] = update_process_sleep(p[i].get('action_parameters'), increase)
+	return p
+
+# function to update timeouts and processes
+def update_timeouts(increase):
+	# updating global timeouts
+	global PAGELOAD_TO, PAGEJS_TO
+	if increase:
+		PAGELOAD_TO *= FACTOR_TO
+		PAGEJS_TO *= FACTOR_TO
+	else:
+		PAGELOAD_TO /= FACTOR_TO
+		PAGEJS_TO /= FACTOR_TO
+	# updating process timeouts
+	global process_portfolio, process_stockinfo, process_buy, process_sell
+	process_portfolio = update_process_sleep(process_portfolio, increase)
+	process_stockinfo = update_process_sleep(process_stockinfo, increase)
+	process_buy = update_process_sleep(process_buy, increase)
+	process_sell = update_process_sleep(process_sell, increase)
+
 # function to enable real/live mode
 def enable_real_mode():
 	global URL_HOME
 	URL_HOME = URL_HOME_BASE.format(FILTER_REAL)
+	if TIMEOUTS_EDITED: update_timeouts(False)
 
 # function to enable practice/demo mode
 def enable_practice_mode():
-	global URL_HOME, PAGELOAD_TO, PAGEJS_TO
+	global URL_HOME
 	URL_HOME = URL_HOME_BASE.format(FILTER_PRACTICE)
-	PAGELOAD_TO *= 3
-	PAGEJS_TO *= 3
+	# updating timeouts
+	update_timeouts(True)
+	# setting timeouts as edited
+	global TIMEOUTS_EDITED
+	TIMEOUTS_EDITED = True
 
 # initiates a connection to URL_HOME
 def initiate_connection(webdriverfile, loginrequired=True):
+	global HOMELOAD_TO
 	return seleniumprocessor.initiate_connection(webdriverfile, get_urlhome(), HOMELOAD_TO, loginrequired)
 
 # retrieves information from a stock with a given ticker, optionally, returning home at the begin/end of the method
@@ -125,6 +158,7 @@ def get_stock_info(brw, ticker, backtohome_begin=True, backtohome_end=True):
 	info = seleniumprocessor.run_process(brw, get_urlhome(), HOMELOAD_TO, tmp_process_stockinfo, backtohome_begin, backtohome_end, checkfilterpassed_callback=checkfilterpassed)
 	# processing output for better presentation
 	if '\n' in info.get('full_price_buy'): info['full_price_buy'] = info.get('full_price_buy').split('\n')[1]
+	if '\n' in info.get('full_price_sell'): info['full_price_sell'] = info.get('full_price_sell').split('\n')[1]
 	info['valuta'] = info.get('full_price_buy')[0]
 	info['price_buy'] = float(info.get('full_price_buy')[1:].replace(',', ''))
 	info['price_sell'] = float(info.get('full_price_sell')[1:].replace(',', ''))
